@@ -34,7 +34,6 @@ enum {
 	AUTOBROWSE,
 	AUTOBURN,
 	AUTOBURN_AUDIO_CD_COMMAND,
-	AUTOBURN_PHOTO_CD_COMMAND,
 	AUTOBURN_DATA_CD_COMMAND,
 	AUTOIPOD,
 	AUTOIPOD_COMMAND,
@@ -46,10 +45,14 @@ enum {
 	AUTOMOUSE_COMMAND,
 	AUTOPHOTO,
 	AUTOPHOTO_COMMAND,
+	AUTOPILOT,
+	AUTOPILOT_COMMAND,
 	AUTOPLAY_CDA,
 	AUTOPLAY_CDA_COMMAND,
 	AUTOPLAY_DVD,
 	AUTOPLAY_DVD_COMMAND,
+	AUTOPOCKETPC,
+	AUTOPOCKETPC_COMMAND,
 	AUTOPRINTER,
 	AUTOPRINTER_COMMAND,
 	AUTORUN,
@@ -72,7 +75,6 @@ static struct {
 	{ GCONF_ROOT "autobrowse",                TYPE_BOOL,   NULL, TRUE  },
 	{ GCONF_ROOT "autoburn",                  TYPE_BOOL,   NULL, FALSE },
 	{ GCONF_ROOT "autoburn_audio_cd_command", TYPE_STRING, NULL, FALSE },
-	{ GCONF_ROOT "autoburn_photo_cd_command", TYPE_STRING, NULL, FALSE },
 	{ GCONF_ROOT "autoburn_data_cd_command",  TYPE_STRING, NULL, FALSE },
 	{ GCONF_ROOT "autoipod",                  TYPE_BOOL,   NULL, TRUE  },
 	{ GCONF_ROOT "autoipod_command",          TYPE_STRING, NULL, FALSE },
@@ -84,10 +86,14 @@ static struct {
 	{ GCONF_ROOT "automouse_command",         TYPE_STRING, NULL, FALSE },
 	{ GCONF_ROOT "autophoto",                 TYPE_BOOL,   NULL, TRUE  },
 	{ GCONF_ROOT "autophoto_command",         TYPE_STRING, NULL, FALSE },
+	{ GCONF_ROOT "autopalmsync",              TYPE_BOOL,   NULL, TRUE  },
+	{ GCONF_ROOT "autopalmsync_command",      TYPE_STRING, NULL, FALSE },
 	{ GCONF_ROOT "autoplay_cda",              TYPE_BOOL,   NULL, TRUE  },
 	{ GCONF_ROOT "autoplay_cda_command",      TYPE_STRING, NULL, FALSE },
 	{ GCONF_ROOT "autoplay_dvd",              TYPE_BOOL,   NULL, TRUE  },
 	{ GCONF_ROOT "autoplay_dvd_command",      TYPE_STRING, NULL, FALSE },
+	{ GCONF_ROOT "autopocketpc",              TYPE_BOOL,   NULL, TRUE  },
+	{ GCONF_ROOT "autopocketpc_command",      TYPE_STRING, NULL, FALSE },
 	{ GCONF_ROOT "autoprinter",               TYPE_BOOL,   NULL, TRUE  },
 	{ GCONF_ROOT "autoprinter_command",       TYPE_STRING, NULL, FALSE },
 	{ GCONF_ROOT "autorun",                   TYPE_BOOL,   NULL, TRUE  },
@@ -225,22 +231,55 @@ close_cb (GtkWidget *dialog,
  * a given GtkImage.
  */
 static void
-set_icon (GtkImage *image, GnomeIconTheme *theme, const char *name)
+set_icon (GtkImage *image, GtkIconTheme *theme, const char *name)
 {
-	char *file;
+	GdkPixbuf *pixbuf;
 	
-	file = gnome_icon_theme_lookup_icon (theme, name, 48, NULL, NULL);
-	if (file) {
-		gtk_image_set_from_file (image, file);
-		g_free (file);
+	if ((pixbuf = gtk_icon_theme_load_icon (theme, name, 48, 0, NULL))) {
+		gtk_image_set_from_pixbuf (image, pixbuf);
+		g_object_unref (pixbuf);
+	}
+}
+
+static struct {
+	const char *name;
+	const char *icon;
+} icons[] = {
+	{ "audio_cd_image",         "gnome-dev-cdrom-audio"   },
+	{ "blank_cd_image",         "gnome-dev-disc-cdr"      },
+	{ "digital_camera_image",   "applets-screenshooter"   },
+	{ "dvd_video_image",        "gnome-dev-dvd"           },
+	{ "ipod_image",             "gnome-dev-ipod"          },
+	{ "keyboard_image",         "gnome-dev-keyboard"      },
+	{ "mouse_image",            "gnome-dev-mouse-optical" },
+	{ "palm_image",             "palm-pilot"              },
+	/* FIXME: need a new icon */
+	{ "pocketpc_image",         "palm-pilot"              },
+	{ "printer_image",          "gnome-dev-printer"       },
+	{ "removable_drives_image", "gnome-dev-removable"     },
+	{ "scanner_image",          "xsane"                   },
+	/* FIXME: need better icon */
+	{ "tablet_image",           "gnome-dev-mouse-optical" },
+	/* FIXME: need better icon */
+	{ "videocam_image",         "gnome-mime-video"        }
+};
+
+static void
+theme_changed_cb (GtkIconTheme *theme, GladeXML *xml)
+{
+	GtkWidget *icon;
+	size_t i;
+	
+	for (i = 0; i < G_N_ELEMENTS (icons); i++) {
+		icon = glade_xml_get_widget (xml, icons[i].name);
+		set_icon (GTK_IMAGE (icon), theme, icons[i].icon);
 	}
 }
 
 static void
 show_props (void)
 {
-	GnomeIconTheme *icon_theme;
-	GtkWidget *icon;
+	GtkIconTheme *theme;
 	char *filename;
 	size_t i;
 	
@@ -267,39 +306,12 @@ show_props (void)
 	props = glade_xml_get_widget (xml, "dialog1");
 	g_signal_connect (props, "response", G_CALLBACK (close_cb), NULL);
 	
-	icon_theme = gnome_icon_theme_new ();
-	
-	icon = glade_xml_get_widget (xml, "removable_drives_image");
-	set_icon (GTK_IMAGE (icon), icon_theme, "gnome-dev-removable");
-	icon = glade_xml_get_widget (xml, "audio_cd_image");
-	set_icon (GTK_IMAGE (icon), icon_theme, "gnome-dev-cdrom-audio");
-	icon = glade_xml_get_widget (xml, "blank_cd_image");
-	set_icon (GTK_IMAGE (icon), icon_theme, "gnome-dev-disc-cdr");
-	icon = glade_xml_get_widget (xml, "dvd_video_image");
-	set_icon (GTK_IMAGE (icon), icon_theme, "gnome-dev-dvd");
-	icon = glade_xml_get_widget (xml, "digital_camera_image");
-	set_icon (GTK_IMAGE (icon), icon_theme, "applets-screenshooter");
-	icon = glade_xml_get_widget (xml, "ipod_image");
-	set_icon (GTK_IMAGE (icon), icon_theme, "gnome-dev-ipod");
-	icon = glade_xml_get_widget (xml, "printer_image");
-	set_icon (GTK_IMAGE (icon), icon_theme, "gnome-dev-printer");
-	icon = glade_xml_get_widget (xml, "scanner_image");
-	set_icon (GTK_IMAGE (icon), icon_theme, "xsane");
-	icon = glade_xml_get_widget (xml, "keyboard_image");
-	set_icon (GTK_IMAGE (icon), icon_theme, "gnome-dev-keyboard");
-	icon = glade_xml_get_widget (xml, "mouse_image");
-	set_icon (GTK_IMAGE (icon), icon_theme, "gnome-dev-mouse-optical");
-	/* FIXME: need better icon */
-	icon = glade_xml_get_widget (xml, "tablet_image");
-	set_icon (GTK_IMAGE (icon), icon_theme, "gnome-dev-mouse-optical");
-	/* FIXME: need better icon */
-	icon = glade_xml_get_widget (xml, "videocam_image");
-	set_icon (GTK_IMAGE (icon), icon_theme, "gnome-mime-video");
+	theme = gtk_icon_theme_get_default ();
+	g_signal_connect (theme, "changed", G_CALLBACK (theme_changed_cb), xml);
+	theme_changed_cb (theme, xml);
 	
 	gtk_window_set_default_icon_name ("gnome-dev-cdrom");
 	
-	g_object_unref (icon_theme);
-	
 	gvm_settings_hash = g_hash_table_new (g_str_hash, g_str_equal);
 	for (i = 0; i < G_N_ELEMENTS (gvm_settings); i++) {
 		const char *name;
@@ -474,7 +486,7 @@ main (int argc, char **argv)
 						 _("Volume management not supported"));
 		gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
 							  _("The \"hald\" service is required but not currently "
-							    "running. Enable the service and rerun this applet, "
+							    "running. Enable the service and rerun this application, "
 							    "or contact your system administrator.\n\n"
 							    "Note: You need Linux kernel 2.6 for volume "
 							    "management to work."));
